API Key
=======

Some features of PyEconomics require access to the FRED API. To use these
features, you need to configure your FRED API access.

A detailed step-by-step guide on obtaining and securely storing your FRED API
key is available here:

- `FRED API Key Configuration Guide (Markdown) <markdown/FRED_API_CONFIGURATION.md>`_
- `FRED API Key Configuration Guide (Jupyter Notebook) <examples/api_configuration/fred_api_configuration.ipynb>`_
